@@ -8,6 +8,7 @@ from sqlalchemy.sql.elements import \
     or_, \
     BinaryExpression
 
+from sqlalchemy.sql.schema import Table
 from .crud_model import RequestResponseModel, CRUDModel
 from .exceptions import QueryOperatorNotFound, PrimaryMissing, UnknownColumn
 from .schema_builder import ApiParameterSchemaBuilder
@@ -31,7 +32,8 @@ __all__ = [
     'find_query_builder',
     'Base',
     'clean_input_fields',
-    'group_find_many_join']
+    'group_find_many_join',
+    'convert_table_to_model']
 
 unsupported_data_types = ["BLOB"]
 partial_supported_data_types = ["INTERVAL", "JSON", "JSONB"]
@@ -94,94 +96,6 @@ def find_query_builder(param: dict, model: Base) -> List[Union[BinaryExpression]
 class OrmConfig(BaseConfig):
     orm_mode = True
 
-
-# def sqlalchemy_table_to_pydantic(db_model: Type, *, crud_methods: List[CrudMethods],
-#                                  exclude_columns: List[str] = None) -> CRUDModel:
-#     if exclude_columns is None:
-#         exclude_columns = []
-#     request_response_mode_set = {}
-#     model_builder = ApiParameterSchemaBuilder_(db_model,
-#                                                exclude_column=exclude_columns)
-#     REQUIRE_PRIMARY_KEY_CRUD_METHOD = [CrudMethods.DELETE_ONE.value,
-#                                        CrudMethods.FIND_ONE.value,
-#                                        CrudMethods.PATCH_ONE.value,
-#                                        CrudMethods.POST_REDIRECT_GET.value,
-#                                        CrudMethods.UPDATE_ONE.value]
-#     for crud_method in crud_methods:
-#         request_url_param_model = None
-#         request_body_model = None
-#         response_model = None
-#         request_query_model = None
-#         if crud_method.value in REQUIRE_PRIMARY_KEY_CRUD_METHOD and not model_builder.primary_key_str:
-#             raise PrimaryMissing(f"The generation of this API [{crud_method.value}] requires a primary key")
-#         if crud_method.value == CrudMethods.UPSERT_ONE.value:
-#             request_query_model, \
-#             request_body_model, \
-#             response_model = model_builder.create_one()
-#         elif crud_method.value == CrudMethods.UPSERT_MANY.value:
-#             request_query_model, \
-#             request_body_model, \
-#             response_model = model_builder.create_many()
-#         elif crud_method.value == CrudMethods.DELETE_ONE.value:
-#             request_url_param_model, \
-#             request_query_model, \
-#             request_body_model, \
-#             response_model = model_builder.delete_one()
-#         elif crud_method.value == CrudMethods.DELETE_MANY.value:
-#             request_url_param_model, \
-#             request_query_model, \
-#             request_body_model, \
-#             response_model = model_builder.delete_many()
-#         elif crud_method.value == CrudMethods.FIND_ONE.value:
-#             request_url_param_model, \
-#             request_query_model, \
-#             request_body_model, \
-#             response_model = model_builder.find_one()
-#         elif crud_method.value == CrudMethods.FIND_MANY.value:
-#             request_query_model, \
-#             request_body_model, \
-#             response_model = model_builder.find_many()
-#         elif crud_method.value == CrudMethods.POST_REDIRECT_GET.value:
-#             request_query_model, \
-#             request_body_model, \
-#             response_model = model_builder.post_redirect_get()
-#         elif crud_method.value == CrudMethods.PATCH_ONE.value:
-#             request_url_param_model, \
-#             request_query_model, \
-#             request_body_model, \
-#             response_model = model_builder.patch()
-#         elif crud_method.value == CrudMethods.UPDATE_ONE.value:
-#             request_url_param_model, \
-#             request_query_model, \
-#             request_body_model, \
-#             response_model = model_builder.update_one()
-#         elif crud_method.value == CrudMethods.UPDATE_MANY.value:
-#             request_url_param_model, \
-#             request_query_model, \
-#             request_body_model, \
-#             response_model = model_builder.update_many()
-#         elif crud_method.value == CrudMethods.PATCH_MANY.value:
-#             request_url_param_model, \
-#             request_query_model, \
-#             request_body_model, \
-#             response_model = model_builder.patch_many()
-#
-#         request_response_models = {'requestBodyModel': request_body_model,
-#                                    'responseModel': response_model,
-#                                    'requestQueryModel': request_query_model,
-#                                    'requestUrlParamModel': request_url_param_model}
-#         request_response_model = RequestResponseModel(**request_response_models)
-#         request_method = CRUDRequestMapping.get_request_method_by_crud_method(crud_method.value).value
-#         if request_method not in request_response_mode_set:
-#             request_response_mode_set[request_method] = {}
-#         request_response_mode_set[request_method][crud_method.value] = request_response_model
-#     return CRUDModel(
-#         **{**request_response_mode_set,
-#            **{"PRIMARY_KEY_NAME": model_builder.primary_key_str,
-#               "UNIQUE_LIST": model_builder.unique_fields}})
-
-
-
 def sqlalchemy_to_pydantic(
         db_model: Type, *,
         crud_methods: List[CrudMethods],
@@ -189,6 +103,8 @@ def sqlalchemy_to_pydantic(
         exclude_columns: List[str] = None,
         constraints = None,
         exclude_primary_key=False) -> CRUDModel:
+
+    db_model, _ = convert_table_to_model(db_model)
     if exclude_columns is None:
         exclude_columns = []
     request_response_mode_set = {}
@@ -407,3 +323,23 @@ def group_find_many_join(list_of_dict: List[dict]) -> List[dict]:
             result = {**i, **response}
         response_list.append(result)
     return response_list
+
+def convert_table_to_model(db_model):
+    NO_PRIMARY_KEY = False
+    if not isinstance(db_model, Table):
+        return db_model, NO_PRIMARY_KEY
+    db_name = str(db_model.fullname)
+    table_dict = {'__table__': db_model,
+                  '__tablename__': db_name}
+
+    if not db_model.primary_key:
+        table_dict['__mapper_args__'] = {
+            "primary_key": [i for i in db_model._columns]
+        }
+        NO_PRIMARY_KEY = True
+
+    for i in db_model.c:
+        col, = i.expression.base_columns
+        table_dict[str(i.key)] = col
+
+    return type(f'{db_name}DeclarativeBaseClass', (declarative_base(),), table_dict), NO_PRIMARY_KEY
